@@ -535,6 +535,12 @@ def toInt(value, default):
     return result
 
 
+def getLimitedValue(value, minValue, maxValue):
+    value = min(value, maxValue)
+    value = max(value, minValue)
+    return value
+
+
 _xPar = "0123456789abcdefghijklmnopqrstuvwxyz"
 
 
@@ -669,22 +675,22 @@ class BytesWriter():
     # -----
 
     def writeShort(self, value):
-        self.write("h", value)  # int16  -32768 ~ +32767
+        self.write("h", getLimitedValue(value, -32768, 32767))  # int16
 
     def writeUShort(self, value):
-        self.write("H", value)  # int16   0 ~ 65535
+        self.write("H", getLimitedValue(value, 0, 65535))  # int16
 
     def writeInt(self, value):
-        self.write("i", value)  # int32  -2147483648 ~ +2147483647
+        self.write("i", getLimitedValue(value, -2147483648, 2147483647))  # int32
 
     def writeUInt(self, value):
-        self.write("I", value)  # int32   0 ~ 4294967295
+        self.write("I", getLimitedValue(value, 0, 4294967295))  # int32
 
     def writeLong(self, value):
-        self.write("q", value)  # int64  -9223372036854775808 ~ +9223372036854775807
+        self.write("q", getLimitedValue(value, -9223372036854775808, 9223372036854775807))  # int64
 
     def writeULong(self, value):
-        self.write("Q", value)  # int64   0 ~ 18446744073709551615
+        self.write("Q", getLimitedValue(value, 0, 18446744073709551615))  # int64
 
     def writeFloat(self, value):
         self.write("f", value)
