@@ -7,14 +7,14 @@ moduleName = None
 parDict = {}
 
 if sys.executable.endswith("python.exe"):
-    projectPath = b.getPath("./../../../")
-    workspacePath = b.getPath("./../../../tool/workspace")
+    workspacePath = b.getPath("./../../workspace")
+    projectPath = workspacePath
     import main_config
     moduleName = main_config.moduleName
     parDict = main_config.parDict
 else:
-    projectPath = b.getPath("./../")
-    workspacePath = b.getPath("./../tool/workspace")
+    workspacePath = b.getPath("./workspace")
+    projectPath = workspacePath
 
 bt.init(projectPath, workspacePath)
 bt.runMain(moduleName, **parDict)
